==> haskell-hakyll-4.13.4.1-122-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hakyll.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hakyll
version:              4.13.4.1
visibility:           public
id:                   hakyll-4.13.4.1-1WvAdZ0lX1FGHJ3rc7lvvy
key:                  hakyll-4.13.4.1-1WvAdZ0lX1FGHJ3rc7lvvy
license:              BSD-3-Clause
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt <m@jaspervdj.be>
homepage:             http://jaspervdj.be/hakyll
synopsis:             A static website compiler library
description:
    Hakyll is a static website compiler library. It provides you with the tools to
    create a simple or advanced static website using a Haskell DSL and formats
    such as markdown or RST. You can find more information, including a tutorial,
    on the website:

    * <http://jaspervdj.be/hakyll>

    If you seek assistance, there'\''s:

    * A google group: <http://groups.google.com/group/hakyll>

    * An IRC channel, @#hakyll@ on freenode

    Additionally, there'\''s the Haddock documentation in the different modules,
    meant as a reference.

category:             Web
abi:                  f6c51c2550e750e549c3bbc7ee52c99d
exposed:              True
exposed-modules:
    Hakyll Hakyll.Commands Hakyll.Core.Compiler
    Hakyll.Core.Compiler.Internal Hakyll.Core.Configuration
    Hakyll.Core.Dependencies Hakyll.Core.File Hakyll.Core.Identifier
    Hakyll.Core.Identifier.Pattern Hakyll.Core.Item Hakyll.Core.Logger
    Hakyll.Core.Metadata Hakyll.Core.Provider
    Hakyll.Core.Provider.Metadata Hakyll.Core.Routes Hakyll.Core.Rules
    Hakyll.Core.Rules.Internal Hakyll.Core.Runtime Hakyll.Core.Store
    Hakyll.Core.UnixFilter Hakyll.Core.Util.File
    Hakyll.Core.Util.String Hakyll.Core.Writable Hakyll.Main
    Hakyll.Web.CompressCss Hakyll.Web.Feed Hakyll.Web.Html
    Hakyll.Web.Html.RelativizeUrls Hakyll.Web.Paginate
    Hakyll.Web.Pandoc Hakyll.Web.Pandoc.Biblio
    Hakyll.Web.Pandoc.FileType Hakyll.Web.Redirect Hakyll.Web.Tags
    Hakyll.Web.Template Hakyll.Web.Template.Context
    Hakyll.Web.Template.Internal Hakyll.Web.Template.Internal.Element
    Hakyll.Web.Template.Internal.Trim Hakyll.Web.Template.List

hidden-modules:
    Data.List.Extended Data.Yaml.Extended Hakyll.Check
    Hakyll.Core.Compiler.Require
    Hakyll.Core.Identifier.Pattern.Internal Hakyll.Core.Item.SomeItem
    Hakyll.Core.Provider.Internal Hakyll.Core.Provider.MetadataCache
    Hakyll.Core.Util.Parser Paths_hakyll Hakyll.Preview.Poll
    Hakyll.Preview.Server Hakyll.Web.Pandoc.Binary

import-dirs:          /usr/lib/ghc-8.10.3/site-local/hakyll-4.13.4.1
library-dirs:         /usr/lib/ghc-8.10.3/site-local/hakyll-4.13.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hakyll
hs-libraries:         HShakyll-4.13.4.1-1WvAdZ0lX1FGHJ3rc7lvvy
depends:
    base-4.14.1.0 binary-0.8.8.0
    blaze-html-0.9.1.2-GmT6EINUyjHvqntCRdaGE
    blaze-markup-0.8.2.7-9sMS9sFEPsZ3VpOkcNgn7I bytestring-0.10.12.0
    containers-0.6.2.1 cryptonite-0.27-DvcguMTH5e8DHN6L8PACh6
    data-default-0.7.1.1-DlCqbdzfJ1T38tQdGVJmqu deepseq-1.4.4.0
    directory-1.3.6.0 file-embed-0.0.13.0-w1EA2BlVGr45s6RdXSQRQ
    filepath-1.4.2.1 fsnotify-0.3.0.1-Cf2vm2ofNdREyPdFRgeqDQ
    http-conduit-2.3.7.4-AMxGZHveMBc88ARHhRryy
    http-types-0.12.3-HetwNy3mgGeDENuBKZCm39
    lrucache-1.2.0.1-HKV8WzGwcQIDlyXe48Vi4z
    memory-0.15.0-E8yvrlcxsw5JtBytoHmuPe mtl-2.2.2
    network-uri-2.6.3.0-G6QUm57NGqYKtD9qNNjs5t
    optparse-applicative-0.16.1.0-GEC7buJinRY4VeApKYshYt
    pandoc-2.11.3-7ZaqGWQpvFE77Nd55ETYu6
    pandoc-citeproc-0.17.0.2-7U8VL5DOBkKKS92wvCyvQr parsec-3.1.14.0
    process-1.6.9.0 random-1.2.0-GQ91GOkO21I1F4AUb9ijR1
    regex-tdfa-1.3.1.0-5le7X06RZCS4yIE6HfZvVg
    resourcet-1.2.4.2-1DyaIM7j2S98tFIrEn9sUe
    scientific-0.3.6.2-CAXwEwe9ZgUFUuXUgTV0go
    tagsoup-0.14.8-BSjrNEg7gvXe6IL6I3a40 template-haskell-2.16.0.0
    text-1.2.4.1 time-1.9.3
    time-locale-compat-0.1.1.5-75n5v6JklqyMdEmBwWBxO
    unordered-containers-0.2.13.0-23W4q6NjyfvEwgc8XDyWoD
    vector-0.12.1.2-2wQfnsplnY91earGv9FMCk
    wai-3.2.3-B7OBDNTm2KzFw7O6nDCu5O
    wai-app-static-3.1.7.2-CFDU31ZCUti3s3kNcRez2a
    warp-3.3.13-J416o7FdeNaADFCxpJpOWZ
    yaml-0.11.5.0-2TZ3GTgBSHV2HpOkcDVSAY

haddock-interfaces:   /usr/share/doc/haskell-hakyll/html/hakyll.haddock
haddock-html:         /usr/share/doc/haskell-hakyll/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hakyll-4.13.4.1-179-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hakyll.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hakyll
version:              4.13.4.1
visibility:           public
id:                   hakyll-4.13.4.1-Lk6S4HXO8Na3aOdWmmxmQH
key:                  hakyll-4.13.4.1-Lk6S4HXO8Na3aOdWmmxmQH
license:              BSD-3-Clause
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt <m@jaspervdj.be>
homepage:             http://jaspervdj.be/hakyll
synopsis:             A static website compiler library
description:
    Hakyll is a static website compiler library. It provides you with the tools to
    create a simple or advanced static website using a Haskell DSL and formats
    such as markdown or RST. You can find more information, including a tutorial,
    on the website:

    * <http://jaspervdj.be/hakyll>

    If you seek assistance, there'\''s:

    * A google group: <http://groups.google.com/group/hakyll>

    * An IRC channel, @#hakyll@ on freenode

    Additionally, there'\''s the Haddock documentation in the different modules,
    meant as a reference.

category:             Web
abi:                  e19b5f7900164313c5926304579ca42e
exposed:              True
exposed-modules:
    Hakyll Hakyll.Commands Hakyll.Core.Compiler
    Hakyll.Core.Compiler.Internal Hakyll.Core.Configuration
    Hakyll.Core.Dependencies Hakyll.Core.File Hakyll.Core.Identifier
    Hakyll.Core.Identifier.Pattern Hakyll.Core.Item Hakyll.Core.Logger
    Hakyll.Core.Metadata Hakyll.Core.Provider
    Hakyll.Core.Provider.Metadata Hakyll.Core.Routes Hakyll.Core.Rules
    Hakyll.Core.Rules.Internal Hakyll.Core.Runtime Hakyll.Core.Store
    Hakyll.Core.UnixFilter Hakyll.Core.Util.File
    Hakyll.Core.Util.String Hakyll.Core.Writable Hakyll.Main
    Hakyll.Web.CompressCss Hakyll.Web.Feed Hakyll.Web.Html
    Hakyll.Web.Html.RelativizeUrls Hakyll.Web.Paginate
    Hakyll.Web.Pandoc Hakyll.Web.Pandoc.Biblio
    Hakyll.Web.Pandoc.FileType Hakyll.Web.Redirect Hakyll.Web.Tags
    Hakyll.Web.Template Hakyll.Web.Template.Context
    Hakyll.Web.Template.Internal Hakyll.Web.Template.Internal.Element
    Hakyll.Web.Template.Internal.Trim Hakyll.Web.Template.List

hidden-modules:
    Data.List.Extended Data.Yaml.Extended Hakyll.Check
    Hakyll.Core.Compiler.Require
    Hakyll.Core.Identifier.Pattern.Internal Hakyll.Core.Item.SomeItem
    Hakyll.Core.Provider.Internal Hakyll.Core.Provider.MetadataCache
    Hakyll.Core.Util.Parser Paths_hakyll Hakyll.Preview.Poll
    Hakyll.Preview.Server Hakyll.Web.Pandoc.Binary

import-dirs:          /usr/lib/ghc-8.10.4/site-local/hakyll-4.13.4.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/hakyll-4.13.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hakyll
hs-libraries:         HShakyll-4.13.4.1-Lk6S4HXO8Na3aOdWmmxmQH
depends:
    base-4.14.1.0 binary-0.8.8.0
    blaze-html-0.9.1.2-1ELBltRztbLDGjYO6xhh0v
    blaze-markup-0.8.2.7-CboNrExa5T26ho9Tvcb2RQ bytestring-0.10.12.0
    containers-0.6.2.1 cryptonite-0.28-5Mx2EJSLFRe6fKgFCaPHck
    data-default-0.7.1.1-JpqGMcmeSO6HucVgz21XKA deepseq-1.4.4.0
    directory-1.3.6.0 file-embed-0.0.13.0-w1EA2BlVGr45s6RdXSQRQ
    filepath-1.4.2.1 fsnotify-0.3.0.1-4Lm1uw3x4ll6B3rOh5JwOy
    http-conduit-2.3.7.4-1BIcW0fBfaC1QZm37Ng8jG
    http-types-0.12.3-AZwPGefh92dGQxWeGkWNmd
    lrucache-1.2.0.1-HKV8WzGwcQIDlyXe48Vi4z
    memory-0.15.0-E8yvrlcxsw5JtBytoHmuPe mtl-2.2.2
    network-uri-2.6.4.1-9hynbczwWel8DN9Llgz8Ot
    optparse-applicative-0.16.1.0-LAb2npSQp2PJwU2s0evoAG
    pandoc-2.11.3-4sZf2BO2qvSDEbHB0Nb989
    pandoc-citeproc-0.17.0.2-E0fKSaES9CoLJa4ZQgqet9 parsec-3.1.14.0
    process-1.6.9.0 random-1.2.0-JaeEP4ACTucH0elcxqGZLW
    regex-tdfa-1.3.1.0-JGQEzvFVQF39kClVWuccwj
    resourcet-1.2.4.2-8VlJo6yN26lBlamTMjWrHN
    scientific-0.3.6.2-DDFmFzdhCtuAWq3jmDNZ4I
    tagsoup-0.14.8-2YK9oDWjse77BErR62jLoU template-haskell-2.16.0.0
    text-1.2.4.1 time-1.9.3
    time-locale-compat-0.1.1.5-75n5v6JklqyMdEmBwWBxO
    unordered-containers-0.2.13.0-3nLuuqaKwKc70HW85Q2c85
    vector-0.12.2.0-1djR9EjNoec73t7OUproRn
    wai-3.2.3-yx7WlXAlzXDefqOE2T0xr
    wai-app-static-3.1.7.2-1LdF2IqV00bD7glGHdG6Dm
    warp-3.3.14-6YwA16MAHL57Ly1YASoPex
    yaml-0.11.5.0-1NLednkJ1eAEZqLc5f87zx

haddock-interfaces:   /usr/share/doc/haskell-hakyll/html/hakyll.haddock
haddock-html:         /usr/share/doc/haskell-hakyll/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
